@@ -1,39 +1,44 @@
 import hashlib
 import logging
-from typing import Tuple, Optional
+from typing import Optional, Tuple
 
-from asn1crypto import keys, algos, pem, x509
+from asn1crypto import algos, keys, pem, x509
 from asn1crypto.keys import PublicKeyInfo
 
 logger = logging.getLogger(__name__)
 
 
 class CryptoBackend:
-
-    def load_private_key(self, key_bytes: bytes, password: Optional[str]) \
-            -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
+    def load_private_key(
+        self, key_bytes: bytes, password: Optional[bytes]
+    ) -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
         raise NotImplementedError
 
     def load_public_key(self, key_bytes: bytes) -> keys.PublicKeyInfo:
         raise NotImplementedError
 
-    def generic_sign(self, private_key: keys.PrivateKeyInfo, tbs_bytes: bytes,
-                     sd_algo: algos.SignedDigestAlgorithm) -> bytes:
+    def generic_sign(
+        self,
+        private_key: keys.PrivateKeyInfo,
+        tbs_bytes: bytes,
+        sd_algo: algos.SignedDigestAlgorithm,
+    ) -> bytes:
         raise NotImplementedError
 
-    def optimal_pss_params(self, key: PublicKeyInfo, digest_algo: str) \
-            -> algos.RSASSAPSSParams:
+    def optimal_pss_params(
+        self, key: PublicKeyInfo, digest_algo: str
+    ) -> algos.RSASSAPSSParams:
         raise NotImplementedError
 
 
 class OscryptoBackend(CryptoBackend):
+    def load_private_key(
+        self, key_bytes: bytes, password: Optional[bytes]
+    ) -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
+        from oscrypto import asymmetric
+        from oscrypto import keys as oskeys
 
-    def load_private_key(self, key_bytes: bytes, password: Optional[str]) \
-            -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
-        from oscrypto import asymmetric, keys as oskeys
-        private = oskeys.parse_private(
-            key_bytes, password=password
-        )
+        private = oskeys.parse_private(key_bytes, password=password)
         if private.algorithm == 'rsassa_pss':
             loaded, public = _oscrypto_hacky_load_pss_exclusive_key(private)
         else:
@@ -43,10 +48,15 @@ class OscryptoBackend(CryptoBackend):
 
     def load_public_key(self, key_bytes: bytes) -> keys.PublicKeyInfo:
         from oscrypto import keys as oskeys
+
         return oskeys.parse_public(key_bytes)
 
-    def generic_sign(self, private_key: keys.PrivateKeyInfo, tbs_bytes: bytes,
-                     sd_algo: algos.SignedDigestAlgorithm) -> bytes:
+    def generic_sign(
+        self,
+        private_key: keys.PrivateKeyInfo,
+        tbs_bytes: bytes,
+        sd_algo: algos.SignedDigestAlgorithm,
+    ) -> bytes:
         from oscrypto import asymmetric
 
         pk_algo = private_key.algorithm
@@ -69,9 +79,7 @@ class OscryptoBackend(CryptoBackend):
             )
         if loaded_key is None:
             loaded_key = asymmetric.load_private_key(private_key)
-        return sign_fun(
-            loaded_key, tbs_bytes, sd_algo.hash_algo
-        )
+        return sign_fun(loaded_key, tbs_bytes, sd_algo.hash_algo)
 
     def optimal_pss_params(self, key: PublicKeyInfo, digest_algo: str):
         key_algo = key.algorithm
@@ -84,24 +92,28 @@ class OscryptoBackend(CryptoBackend):
             )
         # replicate default oscrypto PSS settings
         salt_len = len(getattr(hashlib, digest_algo)().digest())
-        return algos.RSASSAPSSParams({
-            'hash_algorithm': algos.DigestAlgorithm({
-                'algorithm': digest_algo
-            }),
-            'mask_gen_algorithm': algos.MaskGenAlgorithm({
-                'algorithm': 'mgf1',
-                'parameters': algos.DigestAlgorithm(
+        return algos.RSASSAPSSParams(
+            {
+                'hash_algorithm': algos.DigestAlgorithm(
                     {'algorithm': digest_algo}
-                )
-            }),
-            'salt_length': salt_len
-        })
+                ),
+                'mask_gen_algorithm': algos.MaskGenAlgorithm(
+                    {
+                        'algorithm': 'mgf1',
+                        'parameters': algos.DigestAlgorithm(
+                            {'algorithm': digest_algo}
+                        ),
+                    }
+                ),
+                'salt_length': salt_len,
+            }
+        )
 
 
 class PycaCryptographyBackend(CryptoBackend):
-
-    def load_private_key(self, key_bytes: bytes, password: Optional[str]) \
-            -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
+    def load_private_key(
+        self, key_bytes: bytes, password: Optional[bytes]
+    ) -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
         from cryptography.hazmat.primitives import serialization
         from oscrypto import keys as oskeys
 
@@ -123,15 +135,16 @@ class PycaCryptographyBackend(CryptoBackend):
         priv_key = serialization.load_der_private_key(key_bytes, password=None)
         pub_key_bytes = priv_key.public_key().public_bytes(
             encoding=serialization.Encoding.DER,
-            format=serialization.PublicFormat.SubjectPublicKeyInfo
+            format=serialization.PublicFormat.SubjectPublicKeyInfo,
         )
         pub_key_info = keys.PublicKeyInfo.load(pub_key_bytes)
         if priv_key_info.algorithm == 'rsassa_pss':
             # if the private key was a PSS-exclusive one, copy the parameters
             # back from the original (since we stripped them going in)
             # We use .native to get around asn1crypto's type checking
-            pub_key_info['algorithm'] = \
-                priv_key_info['private_key_algorithm'].native
+            pub_key_info['algorithm'] = priv_key_info[
+                'private_key_algorithm'
+            ].native
         return priv_key_info, pub_key_info
 
     def load_public_key(self, key_bytes: bytes) -> keys.PublicKeyInfo:
@@ -139,11 +152,20 @@ class PycaCryptographyBackend(CryptoBackend):
             key_bytes = pem.unarmor(key_bytes)[2]
         return keys.PublicKeyInfo.load(key_bytes)
 
-    def generic_sign(self, private_key: keys.PrivateKeyInfo, tbs_bytes: bytes,
-                     sd_algo: algos.SignedDigestAlgorithm) -> bytes:
-        from cryptography.hazmat.primitives import serialization, hashes
+    def generic_sign(
+        self,
+        private_key: keys.PrivateKeyInfo,
+        tbs_bytes: bytes,
+        sd_algo: algos.SignedDigestAlgorithm,
+    ) -> bytes:
+        from cryptography.hazmat.primitives import hashes, serialization
         from cryptography.hazmat.primitives.asymmetric import (
-            padding, rsa, dsa, ec, ed25519, ed448
+            dsa,
+            ec,
+            ed448,
+            ed25519,
+            padding,
+            rsa,
         )
 
         if private_key.algorithm == 'rsassa_pss':
@@ -161,15 +183,14 @@ class PycaCryptographyBackend(CryptoBackend):
         digest_algorithm = sd_algo.hash_algo
         sig_algo = sd_algo.signature_algo
         if sig_algo == 'rsassa_pkcs1v15':
-            padding = padding.PKCS1v15()
+            asym_padding = padding.PKCS1v15()
             hash_algo = getattr(hashes, digest_algorithm.upper())()
             assert isinstance(priv_key, rsa.RSAPrivateKey)
-            return priv_key.sign(tbs_bytes, padding, hash_algo)
+            return priv_key.sign(tbs_bytes, asym_padding, hash_algo)
         elif sig_algo == 'rsassa_pss':
             parameters = None
             if private_key.algorithm == 'rsassa_pss':
-                key_params = \
-                    private_key['private_key_algorithm']['parameters']
+                key_params = private_key['private_key_algorithm']['parameters']
                 # if the key is parameterised, we must use those params
                 if key_params.native is not None:
                     parameters = key_params
@@ -186,8 +207,7 @@ class PycaCryptographyBackend(CryptoBackend):
 
             mgf_md = getattr(hashes, mgf_md_name.upper())()
             pss_padding = padding.PSS(
-                mgf=padding.MGF1(algorithm=mgf_md),
-                salt_length=salt_len
+                mgf=padding.MGF1(algorithm=mgf_md), salt_length=salt_len
             )
             hash_algo = getattr(hashes, digest_algorithm.upper())()
             assert isinstance(priv_key, rsa.RSAPrivateKey)
@@ -210,14 +230,15 @@ class PycaCryptographyBackend(CryptoBackend):
             return priv_key.sign(tbs_bytes)
         else:  # pragma: nocover
             raise NotImplementedError(
-                f"The signature signature_algo {sig_algo} "
-                f"is unsupported"
+                f"The signature signature_algo {sig_algo} " f"is unsupported"
             )
 
-    def optimal_pss_params(self, key: keys.PublicKeyInfo,
-                           digest_algo: str) -> algos.RSASSAPSSParams:
-        from cryptography.hazmat.primitives.asymmetric import rsa, padding
-        from cryptography.hazmat.primitives import serialization, hashes
+    def optimal_pss_params(
+        self, key: keys.PublicKeyInfo, digest_algo: str
+    ) -> algos.RSASSAPSSParams:
+        from cryptography.hazmat.primitives import hashes, serialization
+        from cryptography.hazmat.primitives.asymmetric import padding, rsa
+
         digest_algo = digest_algo.lower()
 
         if key.algorithm == 'rsassa_pss':
@@ -225,31 +246,36 @@ class PycaCryptographyBackend(CryptoBackend):
             key = key.copy()
             key['algorithm'] = {'algorithm': 'rsa'}
 
-        loaded_key: rsa.RSAPublicKey \
-            = serialization.load_der_public_key(key.dump())
+        loaded_key = serialization.load_der_public_key(key.dump())
+        assert isinstance(loaded_key, rsa.RSAPublicKey)
         md = getattr(hashes, digest_algo.upper())
         # the PSS salt calculation function is not in the .pyi file, apparently.
         # noinspection PyUnresolvedReferences
         optimal_salt_len = padding.calculate_max_pss_salt_length(
             loaded_key, md()
         )
-        return algos.RSASSAPSSParams({
-            'hash_algorithm': algos.DigestAlgorithm({
-                'algorithm': digest_algo
-            }),
-            'mask_gen_algorithm': algos.MaskGenAlgorithm({
-                'algorithm': 'mgf1',
-                'parameters': algos.DigestAlgorithm({
-                    'algorithm': digest_algo
-                }),
-            }),
-            'salt_length': optimal_salt_len
-        })
+        return algos.RSASSAPSSParams(
+            {
+                'hash_algorithm': algos.DigestAlgorithm(
+                    {'algorithm': digest_algo}
+                ),
+                'mask_gen_algorithm': algos.MaskGenAlgorithm(
+                    {
+                        'algorithm': 'mgf1',
+                        'parameters': algos.DigestAlgorithm(
+                            {'algorithm': digest_algo}
+                        ),
+                    }
+                ),
+                'salt_length': optimal_salt_len,
+            }
+        )
 
 
 def pyca_cryptography_present() -> bool:
     try:
         import cryptography
+
         return True
     except ImportError:  # pragma: nocover
         return False
@@ -257,6 +283,7 @@ def pyca_cryptography_present() -> bool:
 
 def _oscrypto_hacky_load_pss_exclusive_key(private: keys.PrivateKeyInfo):
     from oscrypto import asymmetric
+
     # HACK to load PSS-exclusive RSA keys in oscrypto
     #  Don't ever do this in production code!
     algo_copy = private['private_key_algorithm'].native
@@ -270,13 +297,8 @@ def _oscrypto_hacky_load_pss_exclusive_key(private: keys.PrivateKeyInfo):
 
 
 def _select_default_crypto_backend() -> CryptoBackend:
-    from ._asn1crypto_patches import register_attr_cert_patches
-    register_attr_cert_patches()
     # pyca/cryptography required for EdDSA certs
     if pyca_cryptography_present():
-        # Patch EdDSA support into asn1crypto
-        from ._asn1crypto_patches import register_eddsa_oids
-        register_eddsa_oids()
         return PycaCryptographyBackend()
     else:
         return OscryptoBackend()
@@ -285,13 +307,17 @@ def _select_default_crypto_backend() -> CryptoBackend:
 CRYPTO_BACKEND: CryptoBackend = _select_default_crypto_backend()
 
 
-def generic_sign(private_key: keys.PrivateKeyInfo, tbs_bytes: bytes,
-                 signature_algo: algos.SignedDigestAlgorithm) -> bytes:
+def generic_sign(
+    private_key: keys.PrivateKeyInfo,
+    tbs_bytes: bytes,
+    signature_algo: algos.SignedDigestAlgorithm,
+) -> bytes:
     return CRYPTO_BACKEND.generic_sign(private_key, tbs_bytes, signature_algo)
 
 
-def load_private_key(key_bytes: bytes, password: Optional[str]) \
-        -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
+def load_private_key(
+    key_bytes: bytes, password: Optional[bytes]
+) -> Tuple[keys.PrivateKeyInfo, keys.PublicKeyInfo]:
     return CRYPTO_BACKEND.load_private_key(key_bytes, password)
 
 
@@ -299,8 +325,9 @@ def load_public_key(key_bytes: bytes) -> keys.PublicKeyInfo:
     return CRYPTO_BACKEND.load_public_key(key_bytes)
 
 
-def optimal_pss_params(key_algo: keys.PublicKeyInfo, digest_algo: str) \
-        -> algos.RSASSAPSSParams:
+def optimal_pss_params(
+    key_algo: keys.PublicKeyInfo, digest_algo: str
+) -> algos.RSASSAPSSParams:
     return CRYPTO_BACKEND.optimal_pss_params(key_algo, digest_algo)
 
 
@@ -347,7 +374,5 @@ def load_cert_from_pemder(cert_file):
     """
     certs = list(load_certs_from_pemder([cert_file]))
     if len(certs) != 1:
-        raise ValueError(
-            f"Number of certs in {cert_file} should be exactly 1"
-        )
+        raise ValueError(f"Number of certs in {cert_file} should be exactly 1")
     return certs[0]
