@@ -48,9 +48,9 @@ class TimeStamper:
         self,
         tsa_cert: x509.Certificate,
         tsa_key: keys.PrivateKeyInfo,
-        signature_algo: algos.SignedDigestAlgorithm = None,
+        signature_algo: Optional[algos.SignedDigestAlgorithm] = None,
         certs_to_embed=None,
-        fixed_dt: datetime = None,
+        fixed_dt: Optional[datetime] = None,
         policy=tsp.ObjectIdentifier('1.3.6.1.4.1.4146.2.3'),
         md_algorithm='sha256',
     ):
@@ -160,7 +160,7 @@ class CRLBuilder:
         issuer_key: keys.PrivateKeyInfo,
         signature_algo: algos.SignedDigestAlgorithm,
         authority_key_identifier: core.OctetString,
-        extra_crl_extensions: List[TBSCertListExtension] = None,
+        extra_crl_extensions: Optional[List[TBSCertListExtension]] = None,
     ):
         self.issuer_name = issuer_name
         self.issuer_key = issuer_key
@@ -203,9 +203,8 @@ class CRLBuilder:
         serial: int,
         reason: Optional[crl.CRLReason],
         revocation_date: datetime,
-        extensions: List[crl.CRLEntryExtension] = None,
+        extensions: Optional[List[crl.CRLEntryExtension]] = None,
     ) -> crl.RevokedCertificate:
-
         extensions = list(extensions or ())
         if reason is not None:
             extensions.append(
@@ -355,8 +354,8 @@ class SimpleOCSPResponder:
         signature_algo: algos.SignedDigestAlgorithm,
         at_time: datetime,
         revinfo_interface: RevocationInfoInterface,
-        validity: timedelta = timedelta(minutes=10),
-        response_extensions: List[ocsp.ResponseDataExtension] = None,
+        validity: Optional[timedelta] = timedelta(minutes=10),
+        response_extensions: Optional[List[ocsp.ResponseDataExtension]] = None,
     ):
         self.responder_cert = responder_cert
         self.responder_key = responder_key
@@ -373,7 +372,6 @@ class SimpleOCSPResponder:
     def format_single_ocsp_response(
         self, cid: ocsp.CertId, issuer_cert: x509.Certificate
     ) -> ocsp.SingleResponse:
-
         if not issuer_match(cid, issuer_cert):
             raise CertomancerServiceError("Responder is not authorised")
 
@@ -382,16 +380,15 @@ class SimpleOCSPResponder:
             cid, self.at_time
         )
 
-        single_resp = ocsp.SingleResponse(
-            {
-                'cert_id': cid,
-                'cert_status': cert_status,
-                'this_update': self.at_time,
-                'next_update': self.at_time + self.validity,
-                'single_extensions': exts or None,
-            }
-        )
-        return single_resp
+        response_data = {
+            'cert_id': cid,
+            'cert_status': cert_status,
+            'this_update': self.at_time,
+            'single_extensions': exts or None,
+        }
+        if self.validity is not None:
+            response_data['next_update'] = self.at_time + self.validity
+        return ocsp.SingleResponse(response_data)
 
     def build_ocsp_response(self, req: ocsp.OCSPRequest) -> ocsp.OCSPResponse:
         nonce_asn1 = req.nonce_value
